==> question2answer-1.5-language-lt.zip: lt/qa-lang-main.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-main.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases commonly used throughout Q2A


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer' => '1 atsakymas',
		'1_comment' => '1 komentaras',
		'1_day' => '1 diena',
		'1_disliked' => '1 nepatinka',
		'1_flag' => '1 įspėjimas',
		'1_hour' => '1 valanda',
		'1_liked' => '1 patinka',
		'1_minute' => '1 minutė',
		'1_month' => '1 mėnuo',
		'1_point' => '1 taškas',
		'1_question' => '1 klausimas',
		'1_second' => '1 sekundė',
		'1_tag' => '1 žymė',
		'1_user' => '1 vartotojas',
		'1_view' => '1 peržiūra',
		'1_vote' => '1 balsas',
		'1_week' => '1 savaitė',
		'1_year' => '1 metai',
		'add_category_x_favorites' => 'Pridėti kategoriją ^ prie mano mėgstamiausių',
		'add_favorites' => 'Pridėti prie mano mėgstamiausių',
		'add_tag_x_favorites' => 'Pridėti žymę ^ prie mano mėgstamiausių',
		'all_categories' => 'Visos kategorijos',
		'anonymous' => 'anonimas',
		'answer_edited' => 'atsakymas redaguotas',
		'answer_reshown' => 'atsakymas vėl parodytas',
		'answer_selected' => 'atsakymas pažymėtas',
		'answered_qs_in_x' => 'Klausimai su daugiausia atsakymų ^',
		'answered_qs_title' => 'Klausimai su daugiausia atsakymų',
		'answered' => 'atsakytas',
		'asked_related_q' => 'paklausė panašaus klausimo',
		'asked' => 'paklausė',
		'by_x' => '^',
		'cancel_button' => 'Atšaukti',
		'closed' => 'uždarytas',
		'comment_edited' => 'komentaras redaguotas',
		'comment_moved' => 'komentaras perkeltas',
		'comment_reshown' => 'komentaras vėl parodytas',
		'commented' => 'komentuota',
		'date_day_min_digits' => 1, // 1 or 2
		'date_format_other_years' => '^year ^month ^day',
		'date_format_this_year' => '^month ^day',
		'date_month_1' => 'Sau',
		'date_month_2' => 'Vas',
		'date_month_3' => 'Kov',
		'date_month_4' => 'Bal',
		'date_month_5' => 'Geg',
		'date_month_6' => 'Bir',
		'date_month_7' => 'Lie',
		'date_month_8' => 'Rgp',
		'date_month_9' => 'Rgs',
		'date_month_10' => 'Spl',
		'date_month_11' => 'Lap',
		'date_month_12' => 'Grd',
		'date_year_digits' => 4, // 2 or 4
		'edited' => 'redaguotas',
		'field_required' => 'Prašom nepalikti šio lauko tuščio',
		'general_error' => 'Įvyko serverio klaida - prašom pabandyti pakartoti veiksmą.',
		'hidden' => 'paslėptas',
		'highest_users' => 'Vartotojai su daugiausia taškų',
		'hot_qs_in_x' => 'Karšti klausimai ^',
		'hot_qs_title' => 'Karšti klausimai',
		'image_not_read' => 'Nebuvo galima perskaityti paveiksliuko. Prašom atsiųsti vieną iš: ^',
		'image_too_big_x_pc' => 'Šis paveiksliukas yra per didelis. Prašom sumažinti iki ^% ir pabandyti iš naujo.',
		'in_category_x' => '^',
		'ip_address_x' => 'IP adresas ^',
		'logged_in_x' => 'Sveiki ^',
		'max_length_x' => 'Maksimalus ilgis yra ^ simbolių',
		'me' => 'aš',
		'meta_order' => '^what^when^where^who', // you can reorder but DO NOT translate! e.g. <answered> <15 hours ago> <in Problems> <by me (500 points)>
		'min_length_x' => 'Prašom pateikti daugiau informacijos - mažiausiai ^ simbolių',
		'moved' => 'perkelta',
		'nav_account' => 'Mano Paskyra',
		'nav_activity' => 'Visa Veikla',
		'nav_admin' => 'Administravimas',
		'nav_ask' => 'Užduok klausimą',
		'nav_categories' => 'Kategorijos',
		'nav_feedback' => 'Siųsti atsiliepimą',
		'nav_home' => 'Pagrindinis',
		'nav_hot' => 'Karšta!',
		'nav_login' => 'Prisijungti',
		'nav_logout' => 'Atsijungti',
		'nav_most_answers' => 'Daugiausia atsakymų',
		'nav_most_recent' => 'Naujausi',
		'nav_most_views' => 'Daugiausia peržiūrų',
		'nav_most_votes' => 'Daugiausia balsų',
		'nav_no_answer' => 'Nėra atsakymo',
		'nav_no_selected_answer' => 'Nėra patvirtinto atsakymo',
		'nav_no_upvoted_answer' => 'Nėra nubalsuoto atsakymo',
		'nav_qa' => 'Klausimai ir Atsakymai',
		'nav_qs' => 'Klausimai',
		'nav_register' => 'Registruotis',
		'nav_tags' => 'Žymės',
		'nav_unanswered' => 'Neatsakyti',
		'nav_updates' => 'Mano Atnaujinimai',
		'nav_users' => 'Vartotojai',
		'no_active_users' => 'Nerasta aktyvių vartotojų',
		'no_answers_found' => 'Nerasta atsakymų',
		'no_answers_in_x' => 'Nerasta atsakymų ^',
		'no_categories_found' => 'Nerasta kategorijų',
		'no_category' => 'Nėra kategorijų',
		'no_comments_found' => 'Nerasta komentarų',
		'no_comments_in_x' => 'Nerasta komentarų ^',
		'no_questions_found' => 'Nerasta klausimų',
		'no_questions_in_x' => 'Nerasta klausimų ^',
		'no_related_qs_title' => 'Nerasta susijusių klausimų',
		'no_results_for_x' => 'Nieko nerasta paieškai ^',
		'no_tags_found' => 'Nerasta žymių',
		'no_una_questions_found' => 'Nerasta neatsakytų klausimų',
		'no_una_questions_in_x' => 'Nerasta neatsakytų klausimų ^',
		'no_unselected_qs_found' => 'Nerasta klausimų be patvirtinto atsakymo',
		'no_unupvoteda_qs_found' => 'Nerasta klausimų be nubalsuoto atsakymo',
		'page_label' => 'Puslapis:',
		'page_next' => 'sekantis',
		'page_not_found' => 'Puslapis nerastas',
		'page_prev' => 'ankstesnis',
		'popular_tags' => 'Populiariausios žymės',
		'powered_by' => 'Sistema:',
		'questions_tagged_x' => 'Naujausi klausimai su žyme "^"',
		'recategorized' => 'nepriskirti kategorijai',
		'recent_activity_in_x' => 'Naujausia veikla ^',
		'recent_activity_title' => 'Naujausia veikla',
		'recent_as_in_x' => 'Naujausi atsakyti klausimai ^',
		'recent_as_title' => 'Naujausi atsakyti klausimai',
		'recent_cs_in_x' => 'Naujausi komentarai ^',
		'recent_cs_title' => 'Naujausi komentarai',
		'recent_qs_as_in_x' => 'Naujausi klausimai ir atsakymai ^',
		'recent_qs_as_title' => 'Naujausi klausimai ir atsakymai',
		'recent_qs_in_x' => 'Naujausi klausimai ^',
		'recent_qs_title' => 'Naujausi klausimai',
		'related_qs_title' => 'Susiję klausimai',
		'remove_favorites' => 'Pašalinti iš mano mėgstamiausių',
		'remove_x_favorites' => 'Pašalinti ^ iš mano mėgstamiausių',
		'reopened' => 'pakartotinai atidarytas',
		'reshown' => 'pakartotinai parodytas',
		'results_for_x' => 'Paieškos rezultatai užklausai ^',
		'retagged' => 'pažymėtas iš naujo',
		'save_button' => 'Išsaugoti pakeitimus',
		'search_button' => 'Ieškoti',
		'search_explanation' => 'Prašom įvesti užklausos tekstą ir pabandyti iš naujo.',
		'search_title' => 'Paieškos rezultatai',
		'selected' => 'patvirtintas',
		'send_button' => 'Siųsti',
		'suggest_ask' => 'Padėkite aktyvinti mūsų veiklą ^1užduodami klausimą^2.',
		'suggest_category_qs' => 'Daugiau klausimų galima rasti pasirinkus visus ^1klausimus šioje kategorijoje^2.',
		'suggest_qs_tags' => 'Daugiau klausimų galima rasti pasirinkus ^1pilną klausimų sąrašą^2 arba ^3populiariausias žymes^4.',
		'suggest_qs' => 'Daugiau klausimų galima rasti pasirinkus ^1pilną klausimų sąrašą^2.',
		'unanswered_qs_in_x' => 'Klausimai be atsakymų ^',
		'unanswered_qs_title' => 'Naujausi klausimai be atsakymų',
		'unselected_qs_in_x' => 'Klausimai be patvirtinto atsakymo ^',
		'unselected_qs_title' => 'Naujausi klausimai be patvirtinto atsakymo',
		'unupvoteda_qs_in_x' => 'Klausimai be nubalsuoto atsakymo ^',
		'unupvoteda_qs_title' => 'Naujausi klausimai be nubalsuoto atsakymo',
		'upload_limit' => 'Siunčiama per daug duomenų - prašom pabandyti po valandos',
		'view_q_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte peržiūrėti klausimų puslapius.',
		'view_q_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte peržiūrėti klausimų puslapius.',
		'viewed_qs_in_x' => 'Daugiausiai peržiūrėti klausimai ^',
		'viewed_qs_title' => 'Daugiausiai peržiūrėti klausimai',
		'vote_disabled_down' => 'Balsavimas "prieš" yra leidžiamas tik tam tikriems vartotojams',
		'vote_disabled_hidden_a' => 'Jūs negalite balsuoti už paslėptus atsakymus',
		'vote_disabled_hidden_q' => 'Jūs negalite balsuoti už paslėptus klausimus',
		'vote_disabled_level' => 'Balsavimas leidžiamas tik tam tikriems vartotojams',
		'vote_disabled_my_a' => 'Jūs negalite balsuoti už savo atsakymus',
		'vote_disabled_my_q' => 'Jūs negalite balsuoti už savo klausimus',
		'vote_disabled_q_page_only' => 'Prašom prieš balsuojant už šį klausimą jį pirma peržiūrėti',
		'vote_down_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte balsuoti "prieš".',
		'vote_down_popup' => 'Balsuoti "prieš"',
		'vote_limit' => 'Gauta per daug balsų - prašom pabandyti po valandos',
		'vote_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte balsuoti.',
		'vote_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte balsuoti.',
		'vote_not_allowed' => 'Balsavimas yra neleidžiamas',
		'vote_up_popup' => 'Balsuoti "už"',
		'voted_down_popup' => 'Jūs balsavote "prieš" - paspauskite jei norite atšaukti savo balsavimą',
		'voted_qs_in_x' => 'Klausimai su daugiausia balsų ^',
		'voted_qs_title' => 'Klausimai su daugiausia balsų',
		'voted_up_popup' => 'Jūs balsavote "už" - paspauskite jei norite atšaukti savo balsavimą',
		'x_ago' => 'prieš ^',
		'x_answers' => '^ atsakymų',
		'x_comments' => '^ komentarų',
		'x_days' => '^ dienų',
		'x_disliked' => '^ nepatinka',
		'x_flags' => '^ įspėjimų',
		'x_hours' => '^ valandų',
		'x_liked' => '^ patinka',
		'x_minutes' => '^ minučių',
		'x_months' => '^ mėnesių',
		'x_points' => '^ taškų',
		'x_questions' => '^ klausimų',
		'x_seconds' => '^ sekundžių',
		'x_tags' => '^ žymių',
		'x_users' => '^ vartotojų',
		'x_views' => '^ peržiūrų',
		'x_votes' => '^ balsų',
		'x_weeks' => '^ savaičių',
		'x_years' => '^ metų',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.7-language-lt.zip: lt/qa-lang-main.php <==
<?php
/*
	Question2Answer by Gideon Greenspan and contributors
	http://www.question2answer.org/

	File: qa-include/qa-lang-main.php
	Description: Language phrases commonly used throughout Q2A


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_answer' => '1 atsakymas',
		'1_comment' => '1 komentaras',
		'1_day' => '1 diena',
		'1_disliked' => '1 nepatinka',
		'1_flag' => '1 įspėjimas',
		'1_hour' => '1 valanda',
		'1_liked' => '1 patinka',
		'1_minute' => '1 minutė',
		'1_month' => '1 mėnuo',
		'1_point' => '1 taškas',
		'1_question' => '1 klausimas',
		'1_second' => '1 sekundė',
		'1_tag' => '1 žymė',
		'1_user' => '1 vartotojas',
		'1_view' => '1 peržiūra',
		'1_vote' => '1 balsas',
		'1_week' => '1 savaitė',
		'1_year' => '1 metai',
		'add_category_x_favorites' => 'Pridėti kategoriją ^ prie mano mėgstamiausių',
		'add_favorites' => 'Pridėti prie mano mėgstamiausių',
		'add_tag_x_favorites' => 'Pridėti žymę ^ prie mano mėgstamiausių',
		'all_categories' => 'Visos kategorijos',
		'anonymous' => 'anonimas',
		'answer_edited' => 'atsakymas redaguotas',
		'answer_reshown' => 'atsakymas vėl parodytas',
		'answer_selected' => 'atsakymas pažymėtas',
		'answered' => 'atsakytas',
		'answered_qs_in_x' => 'Klausimai su daugiausia atsakymų ^',
		'answered_qs_title' => 'Klausimai su daugiausia atsakymų',
		'asked' => 'paklausė',
		'asked_related_q' => 'paklausė panašaus klausimo',
		'by_x' => '^',
		'cancel_button' => 'Atšaukti',
		'closed' => 'uždarytas',
		'comment_edited' => 'komentaras redaguotas',
		'comment_moved' => 'komentaras perkeltas',
		'comment_reshown' => 'komentaras vėl parodytas',
		'commented' => 'komentuota',
		'date_day_min_digits' => 1, // 1 or 2
		'date_format_other_years' => '^year ^month ^day',
		'date_format_this_year' => '^month ^day',
		'date_month_1' => 'Sau',
		'date_month_2' => 'Vas',
		'date_month_3' => 'Kov',
		'date_month_4' => 'Bal',
		'date_month_5' => 'Geg',
		'date_month_6' => 'Bir',
		'date_month_7' => 'Lie',
		'date_month_8' => 'Rgp',
		'date_month_9' => 'Rgs',
		'date_month_10' => 'Spl',
		'date_month_11' => 'Lap',
		'date_month_12' => 'Grd',
		'date_year_digits' => 4, // 2 or 4
		'edited' => 'redaguotas',
		'email_error' => 'Įvyko klaida siunčiant el. laišką.',
		'field_required' => 'Prašome nepalikti šio lauko tuščio',
		'file_upload_limit_exceeded' => 'Failo dydis viršija serverio limitus',
		'general_error' => 'Įvyko serverio klaida - prašome pabandyti pakartoti veiksmą.',
		'hidden' => 'paslėptas',
		'highest_users' => 'Vartotojai su daugiausia taškų',
		'hot_qs_in_x' => 'Karšti klausimai ^',
		'hot_qs_title' => 'Karšti klausimai',
		'image_not_read' => 'Nebuvo galima perskaityti paveiksliuko. Prašom atsiųsti vieną iš: ^',
		'image_too_big_x_pc' => 'Šis paveiksliukas yra per didelis. Prašom sumažinti iki ^% ir pabandyti iš naujo.',
		'in_category_x' => '^',
		'ip_address_x' => 'IP adresas ^',
		'logged_in_x' => 'Sveiki ^',
		'max_length_x' => 'Maksimalus ilgis yra ^ simbolių',
		'max_upload_size_x' => 'Maksimalus failo dydis yra ^',
		'me' => 'aš',
		'meta_order' => '^what^when^where^who', // you can reorder but DO NOT translate! e.g. <answered> <15 hours ago> <in Problems> <by me (500 points)>
		'min_length_x' => 'Prašom pateikti daugiau informacijos - mažiausiai ^ simbolių',
		'moved' => 'perkelta',
		'nav_activity' => 'Visa Veikla',
		'nav_admin' => 'Administravimas',
		'nav_ask' => 'Užduok klausimą',
		'nav_categories' => 'Kategorijos',
		'nav_feedback' => 'Siųsti atsiliepimą',
		'nav_home' => 'Pagrindinis',
		'nav_hot' => 'Karšta!',
		'nav_login' => 'Prisijungti',
		'nav_logout' => 'Atsijungti',
		'nav_most_answers' => 'Daugiausia atsakymų',
		'nav_most_recent' => 'Naujausi',
		'nav_most_views' => 'Daugiausia peržiūrų',
		'nav_most_votes' => 'Daugiausia balsų',
		'nav_no_answer' => 'Nėra atsakymo',
		'nav_no_selected_answer' => 'Nėra patvirtinto atsakymo',
		'nav_no_upvoted_answer' => 'Nėra nubalsuoto atsakymo',
		'nav_qa' => 'Klausimai ir Atsakymai',
		'nav_qs' => 'Klausimai',
		'nav_register' => 'Registruotis',
		'nav_tags' => 'Žymės',
		'nav_unanswered' => 'Neatsakyti',
		'nav_updates' => 'Mano Atnaujinimai',
		'nav_users' => 'Vartotojai',
		'no_active_users' => 'Nerasta aktyvių vartotojų',
		'no_answers_found' => 'Nerasta atsakymų',
		'no_answers_in_x' => 'Nerasta atsakymų ^',
		'no_categories_found' => 'Nerasta kategorijų',
		'no_category' => 'Nėra kategorijų',
		'no_comments_found' => 'Nerasta komentarų',
		'no_comments_in_x' => 'Nerasta komentarų ^',
		'no_questions_found' => 'Nerasta klausimų',
		'no_questions_in_x' => 'Nerasta klausimų ^',
		'no_related_qs_title' => 'Nerasta susijusių klausimų',
		'no_results_for_x' => 'Nieko nerasta paieškai ^',
		'no_tags_found' => 'Nerasta žymių',
		'no_una_questions_found' => 'Nerasta neatsakytų klausimų',
		'no_una_questions_in_x' => 'Nerasta neatsakytų klausimų ^',
		'no_unselected_qs_found' => 'Nerasta klausimų be patvirtinto atsakymo',
		'no_unupvoteda_qs_found' => 'Nerasta klausimų be nubalsuoto atsakymo',
		'page_label' => 'Puslapis:',
		'page_next' => 'sekantis',
		'page_not_found' => 'Puslapis nerastas',
		'page_prev' => 'ankstesnis',
		'popular_tags' => 'Populiariausios žymės',
		'questions_tagged_x' => 'Naujausi klausimai su žyme "^"',
		'recategorized' => 'nepriskirti kategorijai',
		'recent_activity_in_x' => 'Naujausia veikla ^',
		'recent_activity_title' => 'Naujausia veikla',
		'recent_as_in_x' => 'Naujausi atsakyti klausimai ^',
		'recent_as_title' => 'Naujausi atsakyti klausimai',
		'recent_cs_in_x' => 'Naujausi komentarai ^',
		'recent_cs_title' => 'Naujausi komentarai',
		'recent_qs_as_in_x' => 'Naujausi klausimai ir atsakymai ^',
		'recent_qs_as_title' => 'Naujausi klausimai ir atsakymai',
		'recent_qs_in_x' => 'Naujausi klausimai ^',
		'recent_qs_title' => 'Naujausi klausimai',
		'related_qs_title' => 'Susiję klausimai',
		'remove_favorites' => 'Pašalinti iš mano mėgstamiausių',
		'remove_x_favorites' => 'Pašalinti ^ iš mano mėgstamiausių',
		'reopened' => 'pakartotinai atidarytas',
		'reshown' => 'pakartotinai parodytas',
		'results_for_x' => 'Paieškos rezultatai užklausai ^',
		'retagged' => 'pažymėtas iš naujo',
		'save_button' => 'Išsaugoti pakeitimus',
		'search_button' => 'Ieškoti',
		'search_explanation' => 'Prašom įvesti užklausos tekstą ir pabandyti iš naujo.',
		'search_title' => 'Paieškos rezultatai',
		'selected' => 'patvirtintas',
		'send_button' => 'Siųsti',
		'since_x' => 'nuo ^',
		'suggest_ask' => 'Padėkite aktyvinti mūsų veiklą ^1užduodami klausimą^2.',
		'suggest_category_qs' => 'Daugiau klausimų galima rasti pasirinkus visus ^1klausimus šioje kategorijoje^2.',
		'suggest_qs' => 'Daugiau klausimų galima rasti pasirinkus ^1pilną klausimų sąrašą^2.',
		'suggest_qs_tags' => 'Daugiau klausimų galima rasti pasirinkus ^1pilną klausimų sąrašą^2 arba ^3populiariausias žymes^4.',
		'to_x' => 'iki ^',
		'unanswered_qs_in_x' => 'Klausimai be atsakymų ^',
		'unanswered_qs_title' => 'Naujausi klausimai be atsakymų',
		'unselected_qs_in_x' => 'Klausimai be patvirtinto atsakymo ^',
		'unselected_qs_title' => 'Naujausi klausimai be patvirtinto atsakymo',
		'unupvoteda_qs_in_x' => 'Klausimai be nubalsuoto atsakymo ^',
		'unupvoteda_qs_title' => 'Naujausi klausimai be nubalsuoto atsakymo',
		'upload_limit' => 'Siunčiama per daug duomenų - prašom pabandyti po valandos',
		'view_q_must_be_approved' => 'Jūsų paskyra turi būti patvirtinta, kad galėtumėte peržiūrėti klausimų puslapius.',
		'view_q_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte peržiūrėti klausimų puslapius.',
		'view_q_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte peržiūrėti klausimų puslapius.',
		'viewed_qs_in_x' => 'Daugiausiai peržiūrėti klausimai ^',
		'viewed_qs_title' => 'Daugiausiai peržiūrėti klausimai',
		'vote_disabled_approve' => 'Prieš jums balsuojant jūsų paskyra turi būti patvirtinta',
		'vote_disabled_down' => 'Balsavimas "prieš" yra leidžiamas tik tam tikriems vartotojams',
		'vote_disabled_down_approve' => 'Prieš jums balsuojant "prieš" jūsų paskyra turi būti patvirtinta',
		'vote_disabled_hidden_a' => 'Jūs negalite balsuoti už paslėptus atsakymus',
		'vote_disabled_hidden_q' => 'Jūs negalite balsuoti už paslėptus klausimus',
		'vote_disabled_level' => 'Balsavimas leidžiamas tik tam tikriems vartotojams',
		'vote_disabled_my_a' => 'Jūs negalite balsuoti už savo atsakymus',
		'vote_disabled_my_q' => 'Jūs negalite balsuoti už savo klausimus',
		'vote_disabled_q_page_only' => 'Prašom prieš balsuojant už šį klausimą jį pirma peržiūrėti',
		'vote_down_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte balsuoti "prieš".',
		'vote_down_popup' => 'Balsuoti "prieš"',
		'vote_limit' => 'Gauta per daug balsų - prašom pabandyti po valandos',
		'vote_must_confirm' => 'Prašom ^5patvirtinti savo el. pašto adresą^6 tam, kad galėtumėte balsuoti.',
		'vote_must_login' => 'Prašom ^1prisijungti^2 arba ^3prisiregistruoti^4 tam, kad galėtumėte balsuoti.',
		'vote_not_allowed' => 'Balsavimas yra neleidžiamas',
		'vote_up_popup' => 'Balsuoti "už"',
		'voted_down_popup' => 'Jūs balsavote "prieš" - paspauskite jei norite atšaukti savo balsavimą',
		'voted_qs_in_x' => 'Klausimai su daugiausia balsų ^',
		'voted_qs_title' => 'Klausimai su daugiausia balsų',
		'voted_up_popup' => 'Jūs balsavote "už" - paspauskite jei norite atšaukti savo balsavimą',
		'written' => '', // blank in English - placeholder for other languages
		'x_ago' => 'prieš ^',
		'x_answers' => '^ atsakymų',
		'x_comments' => '^ komentarų',
		'x_days' => '^ dienų',
		'x_disliked' => '^ nepatinka',
		'x_flags' => '^ įspėjimų',
		'x_hours' => '^ valandų',
		'x_liked' => '^ patinka',
		'x_minutes' => '^ minučių',
		'x_months' => '^ mėnesių',
		'x_points' => '^ taškų',
		'x_questions' => '^ klausimų',
		'x_seconds' => '^ sekundžių',
		'x_tags' => '^ žymių',
		'x_users' => '^ vartotojų',
		'x_views' => '^ peržiūrų',
		'x_votes' => '^ balsų',
		'x_weeks' => '^ savaičių',
		'x_years' => '^ metų',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
